# DAMASK - The Düsseldorf Advanced Material Simulation Kit

- Usage, installation, and support: https://damask.mpie.de
- Code development: https://git.damask.mpie.de
- General inquiries: damask@mpie.de


## Repository Locations

### [git.damask.mpie.de](https://git.damask.mpie.de)

All code development is centralized in the principal DAMASK code repository hosted at [git.damask.mpie.de](https://git.damask.mpie.de).
Access to this GitLab instance requires registration and is granted to anyone with an interest in actively supporting the development of DAMASK.

### [github.com](https://github.com)

GitHub hosts the publicly accessible, but read-only, mirror of the principal DAMASK code repository and replicates its three top-level branches from [git.damask.mpie.de](https://git.damask.mpie.de).

The site is primarily meant to provide a forum for [Discussions](https://github.com/eisenforschung/DAMASK/discussions) and [Issues](https://github.com/eisenforschung/DAMASK/issues).


## Contact Information

Max-Planck-Institut für Eisenforschung GmbH  
Max-Planck-Str. 1  
40237 Düsseldorf  
Germany  

## Version Information

Revision v3.0.0-alpha8  
Exported on Tue 14 Nov 2023 17:07:40 CET  

